#
# spec file for package tint2
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           tint2
Version:        0.14.6
Release:        1.1
Summary:        A lightweight X11 desktop panel and task manager
License:        GPL-2.0
Group:          System/X11/Utilities
Url:            https://gitlab.com/o9000/tint2
Source0:        https://gitlab.com/o9000/%{name}/repository/archive.tar.gz?ref=v%{version}#/%{name}-%{version}.tar.gz
BuildRequires:  cairo-devel
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  gcc-c++
BuildRequires:  gettext
BuildRequires:  gtk2-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  imlib2-devel
BuildRequires:  libXcomposite-devel
BuildRequires:  libXdamage-devel
BuildRequires:  libXinerama-devel
BuildRequires:  libXrandr-devel
BuildRequires:  libXrender-devel
BuildRequires:  librsvg2-devel
BuildRequires:  pango-devel
BuildRequires:  startup-notification-devel
Recommends:     %{name}-lang

%description
tint2 is a simple panel/taskbar made for modern X window managers. It was
specifically made for Openbox3 but should also work with other window managers.

%lang_package

%prep
%setup -q -n %{name}-v%{version}-8046600a552774253939b8a83bdd3fc0e60dacec/

%build
%cmake -DENABLE_EXAMPLES=ON -DDOCDIR=%{_docdir}/%{name}
make %{?_smp_mflags}

%install
%cmake_install

# put sample/ in %%doc
rm -rf %{buildroot}%{_datadir}/tint2/*.tint2rc

# create tint2 config directory
mkdir -p %{buildroot}%{_sysconfdir}/skel/.config/tint2/

desktop-file-install	\
	--set-key=NoDisplay  --set-value=true	\
	--delete-original	\
	--dir=%{buildroot}%{_datadir}/applications	\
	%{buildroot}/%{_datadir}/applications/tint2.desktop

desktop-file-install	\
	--delete-original	\
	--dir=%{buildroot}%{_datadir}/applications	\
	%{buildroot}/%{_datadir}/applications/tint2conf.desktop

%find_lang tint2conf

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%defattr(-,root,root)
%doc COPYING
%{_bindir}/tint2
%{_bindir}/tint2conf
%config(noreplace) %{_sysconfdir}/xdg/tint2/tint2rc
%{_sysconfdir}/skel/.config/tint2/
%{_sysconfdir}/xdg/tint2
%{_datadir}/tint2/
%{_datadir}/applications/tint2conf.desktop
%{_datadir}/applications/tint2.desktop
%{_datadir}/icons/hicolor/*/apps/tint*
%{_mandir}/man1/tint*
%dir %{_datadir}/doc/tint2
%dir %{_datadir}/doc/tint2/html
%dir %{_datadir}/doc/tint2/html/images
%{_datadir}/doc/tint2/*
%{_datadir}/mime/packages/tint2conf.xml

%files lang -f tint2conf.lang
%defattr(-,root,root)

%changelog
* Thu Jun 22 2017 mvetter@suse.com
- Update to 0.14.6:
  Fixes:
  * Make versioning more robust when building as package
  * Fix regression in executor (issue #639)
  * Fix crash when _NET_WM_ICON is set but empty (https://github.com/jmc-88/tint3/issues/21)
  * Take into account border width when computing text height
  * Taskbar: Fix task icon size limits
  * Executor: Do not output last line if it is not terminated by newline
  * Fixed a couple of memory leaks
  Enhancements:
  * Tint2conf: Open current tint2 config automatically when started from tint2
  * Re-execute tint2 on SIGUSR2.
    This is useful for preserving config options and environment when updating tint2.
- Add File: tint2conf.xml
* Fri Mar 31 2017 mvetter@suse.com
- Update to 0.14.1:
  * Fixed tint2conf problem under FreeBSD (or generally any system using clang).
* Sun Mar 12 2017 mvetter@suse.com
- Update to 0.13.1:
  * Fixed compilation with new glibc (issue #625)
  * Fixed regression in distributing size between taskbars (issue #628)
  * Create ~/.config dir if it does not exist (issue #629)
  * New config option systray_name_filter to hide hide specific apps from the system tray (contributed by Matthew Otnel)
  * Tint2conf: minor improvements
- Adjust Group from User Interface/Desktops to System/X11/Utilities
- Install new doc files
* Mon Sep 12 2016 mvetter@suse.com
- Update to 0.12.12:
  Fixes:
  * Set task maximum height equal to width if not specified, instead of hardcoding 30 (issue #583; thanks @VastOne)
  * tint2conf
  * Process background selection events correctly (issue #582)
  * Menus accessible with keyboard shortcuts (issue #590)
  Enhancements:
  * Borders can now be drawn on only some sides; configurable with the option border_sides (issue #580; thanks @stophe)
  * Updated man page
  * The geometry of panel items is printed to stderr if the environment variable DEBUG_GEOMETRY is set
* Tue Jul 12 2016 mvetter@suse.com
- Update to 0.12.11:
  * Fixed crash in tint2conf when adding background
  * Add correct extension to file name in tint2conf for 'Save as'
  * Changed main window title in tint2conf
* Thu May 12 2016 mvetter@suse.com
- Update to 0.12.10:
  * Fixed crash in systray with non-Latin languagess (thanks zcodes)
  * Invalidate cached pixmaps on resize/move (issue #576)
  * Battery: do not show negative durations when the sensors return garbage
  * Proper workaround for issue #555
* Mon Apr  4 2016 mvetter@suse.com
- Update to 0.12.9:
- Remove tint2_ppc64le_linux.patch: Upstreamed
* Fri Mar 18 2016 normand@linux.vnet.ibm.com
-  add tint2_ppc64le_linux.patch to avoid PowerPC build failure
* Fri Feb 12 2016 mvetter@suse.com
- Update to version 0.12.7:
  Fixes:
  * Fix crash caused by race when reading inconsistent values for _NET_CURRENT_DESKTOP and _NET_NUMBER_OF_DESKTOPS
  * Fix regression (all desktop tasks not working)
  * Fix small memory leak in launcher
  * Fix crash on 32-bit systems (issue #546)
  * Fix compilation on Slackware (issue #547)
  * Terminal color reset code moved to the same line to prevent interference with logging (issue #545)
  * Fix rendering corruption triggered occasionally when the compositor is disabled (regression in 0.12.4)
  * Battery changes visibility correctly (issue #531)
  * Fixed rendering corruption (issue #543)
  * Reverted the window flags back to the value in 0.11 to make sure the window manager detects that tint2 is a panel.
  * Fixed a rare crash caused by the system tray code
  * The system tray now reorders icons correctly when the icon name changes and the sorting order is configured as ascending or descending (affected GTK icons, which sometimes set their name late after creating the icon)
  * Tint2conf no longer copies sample themes to ~/.config
  * New optional dependencies:
  * libexecinfo on the *BSDs (only if the cmake flag ENABLE_BACKTRACE is set)
  * The correct icon is now used in tint2.desktop (issue #523)
  * The font setting for the desktop name is no longer lost on tint2 restart
  Enhancements:
  * Executor now sends click coordinates via environment variables (issue #544)
  * Support for NETWM viewports (as used by Compiz or Unity) (issue #94)
  * The default desktop font (Gtk/FontName from XSettings) is used when a font is not specified in the config file
  * When no fonts are specified in the config, tint2 picks up the default font of the desktop environment via XSettings
  * Tint2 is now able to dump a stack trace to stderr and ~/.tint2-crash.log in case of a crash.
  * Pixmaps are cached instead of always redrawn between different button states when mouse effects are enabled, to improve performance
  * Tooltips are no longer very wide
  * Default config looks nicer
  * Battery: Multiple batteries are now supported under Linux
  * Battery: The time left for charging/discharging the battery is now estimated when the system is not able to read current data from sensors
  * Battery: Reacts to plug/unplug events
  * tint2conf: Backgrounds now have a text label showing which panel component uses them, to make them easier to identify
  New config options:
  * Executor: new plugin that displays the output of a command in the panel (issue #161)
  * New taskbar sort order options: least-recently-used (lru), most-recently-used (mru) (issue #532)
  * Place the primary monitor before all the other monitors (primary_monitor_first, issue #538)
  * taskbar_always_show_all_desktop_tasks (issue #279)
  * Config options with changed behavior:
  * Mouse effects are enabled by default
  * Mouse over effects (mouse_effects, background_color_hover, border_color_hover)
  * Launcher icon background (launcher_icon_background_id)
  * Enable/disable battery tooltips (battery_tooltip_enabled)
* Wed Jul 15 2015 mvetter@suse.com
- Initial package for version 0.12
